@@ -11,7 +11,7 @@
 *                                                                         *
 * The above copyright notice and this permission notice shall be included *
 * in all copies or substantial portions of the Software.                  *
-// // *                                                                         *
+*                                                                         *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF              *
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  *
@@ -51,9 +51,10 @@
 #endif
 
 
-struct exchangeData_s {
+struct exchangeData_s
+{
     struct MatchMaker::Partner partners[ 2 ];
-    bool deleteOnDevice;
+    int deleteOnDevice;
 };
 
 
@@ -64,9 +65,12 @@ PDA::PDA( Raki *raki, QString pdaName )
     _masqueradeStarted = false;
     partnerOk = false;
     typesRead = false;
+    alreadySynced = false;
     this->raki = raki;
     this->pdaName = pdaName;
     this->rra = new Rra( pdaName );
+    this->rra->setLogLevel(0);
+    this->ptd = new PDAThreadData(this);
 
     runWindow = new RunWindowImpl( pdaName, raki, "RunWindow", false );
     runWindow->setCaption( i18n( "Execute on %1" ).arg( pdaName ) );
@@ -146,15 +150,19 @@ PDA::~PDA()
 
     delete passwordDialog;
     delete runWindow;
-    if ( managerWindow->running() ) {
+    if (managerWindow->running() ) {
         managerWindow->setDelayedDelete( true );
         managerWindow->WorkerThreadInterface::setStopRequested( true );
     } else {
         delete managerWindow;
     }
+    if (configDialog->getOsVersion() > 3) {
+        this->rra->disconnect();
+    }
     delete configDialog;
     delete associatedMenu;
     delete rra;
+    delete ptd;
 
     slaveDict.setAutoDelete( true );
 }
@@ -198,7 +206,7 @@ void PDA::setStopRequested( bool isStopRequested )
 }
 
 
-bool PDA::getSynchronizationTypes( QMap<int, RRA_SyncMgrType *> *types )
+bool PDA::getSynchronizationTypes( QValueList<uint32_t> *types )
 {
     return rra->getTypes( types );
 }
@@ -249,10 +257,15 @@ void PDA::openFs()
 
 void PDA::synchronize( bool forced )
 {
-    if ( ( forced || configDialog->getSyncAtConnect() ) && isPartner() ) {
+    if (!alreadySynced && ( forced || configDialog->getSyncAtConnect() ) && isPartner() ) {
         QPtrList<SyncTaskListItem>& syncItems =
             configDialog->getSyncTaskItemList();
         syncDialog->show( syncItems );
+        if (configDialog->getOsVersion() > 3) {
+            alreadySynced = true;
+        }
+    } else if (alreadySynced) {
+        KMessageBox::sorry((QWidget * ) parent(), QString(i18n("The device has already been synced. This could not be done twice. Please disconnect and reconnect your device and start syncing again.")));
     }
 }
 
@@ -382,13 +395,13 @@ QString PDA::getDeviceIp()
 
 void *PDA::removePartnershipDialog( void *data )
 {
-    struct exchangeData_s *exchangeData = (struct exchangeData_s *) data;
+    struct exchangeData_s * exchangeData = ( struct exchangeData_s * ) data;
 
     initProgress->hide();
 
     exchangeData->deleteOnDevice = RemovePartnershipDialogImpl::showDialog(
-                          QString( exchangeData->partners[ 0 ].name ), QString( exchangeData->partners[ 1 ].name ) , 0,
-                          "Remove Partnership", true, 0 );
+                                       QString( exchangeData->partners[ 0 ].name ), QString( exchangeData->partners[ 1 ].name ) , 0,
+                                       "Remove Partnership", true, 0 );
 
     initProgress->show();
 
@@ -409,7 +422,7 @@ void *PDA::alreadyTwoPartnershipsDialog( void * )
 
 void *PDA::removeLocalPartnershipDialog( void *removeOnDesktop_v )
 {
-    bool *removeOnDesktop = (bool *) removeOnDesktop_v;
+    bool * removeOnDesktop = ( bool * ) removeOnDesktop_v;
 
     int answer = KMessageBox::questionYesNo( ( QWidget * ) parent(),
                  i18n( "A Partnership with name %1 already exists "
@@ -433,13 +446,14 @@ bool PDA::isPartner()
 
 void *PDA::progressDialogCancel( void *status_p )
 {
-    int *status = (int *) status_p;
+    int * status = ( int * ) status_p;
     initProgress->hide();
-    emit initialized( this, *status);
+    emit initialized( this, *status );
     delete initProgress;
     if ( *status ) {
         configDialog->writeConfig();
     }
+    delete status;
 
     return NULL;
 }
@@ -453,12 +467,11 @@ void *PDA::rraConnectionError( void * )
 }
 
 
-void PDA::setPartnership( QThread */*thread*/, void * )
+void PDA::setPartnership( QThread * /*thread*/, void * )
 {
     struct MatchMaker::Partner partners[ 2 ];
-    struct MatchMaker::Partner partner;
     MatchMaker matchmaker( pdaName );
-    uint32_t matchingPartnerId = 0;
+    uint32_t devicePartnerIndex = 0;
     bool onDesktopKnown = false;
     bool removeOnDesktop = false;
     bool twoOnDevice = false;
@@ -466,42 +479,42 @@ void PDA::setPartnership( QThread */*thread*/, void * )
     bool useGuest = false;
     int deleteOnDevice = 0;
 
-    kdDebug(2120) << i18n("Connecting to the device ...") << endl;
+    kdDebug( 2120 ) << i18n( "Connecting to the device ..." ) << endl;
     if ( matchmaker.connect() ) {
-// 1
+        // 1
         advanceInitProgress( 1 );
 
-        kdDebug(2120) << i18n("success") << endl;
+        kdDebug( 2120 ) << i18n( "success" ) << endl;
         kdDebug( 2120 ) << i18n( "Reading from device ...." ) << endl;
-        for ( int i = 0; ( i < 2 ) && ( matchingPartnerId == 0 ); i++ ) {
+        for ( int i = 0; ( i < 2 ) && ( devicePartnerIndex == 0 ); i++ ) {
             kdDebug( 2120 ) << i18n( "    get partnership with index %1 ..." ).arg( i + 1 ) << endl;
             if ( matchmaker.getPartner( i + 1, &partners[ i ] ) ) {
                 kdDebug( 2120 ) << i18n( "    success" ) << endl;
                 if ( partners[ i ].name == configDialog->getPartnerName() &&
-                            partners[ i ].id == configDialog->getPartnerId() ) {
+                        partners[ i ].id == configDialog->getPartnerId() ) {
                     kdDebug( 2120 ) << i18n( "        matching!" ) << endl;
-                    matchingPartnerId = i + 1;
-                    partner = partners[ i ];
+                    devicePartnerIndex = i + 1;
+                    partnerId = partners[i].id;
                 }
             } else {
                 kdDebug( 2120 ) << i18n( "    failed" ) << endl;
             }
-// 3
+            // 3
             advanceInitProgress( 1 );
 
         }
         kdDebug( 2120 ) << i18n( "finished" ) << endl;
 
-        if ( matchingPartnerId > 0 ) {
+        if ( devicePartnerIndex > 0 ) {
             kdDebug( 2120 ) << i18n( "Matching partnership found ..." ) << endl;
             kdDebug( 2120 ) << i18n( "    Trying to make it valid on the Device ... " ) << endl;
-            if ( matchmaker.setCurrentPartner( matchingPartnerId ) ) {
+            if ( matchmaker.setCurrentPartner( devicePartnerIndex ) ) {
                 kdDebug( 2120 ) << i18n( "        success!" ) << endl;
             } else {
                 error = true;
                 kdDebug( 2120 ) << i18n( "        failed!" );
             }
-// 4
+            // 4
             advanceInitProgress( 1 );
 
         } else {
@@ -515,7 +528,7 @@ void PDA::setPartnership( QThread */*thread*/, void * )
                 kdDebug( 2120 ) << i18n( "    We should ask user if partnership on the desktop should be deleted" ) << endl;
                 postThreadEvent( &PDA::removeLocalPartnershipDialog, &removeOnDesktop, block );
             }
-// 5
+            // 5
             advanceInitProgress( 1 );
 
             if ( ( onDesktopKnown && removeOnDesktop ) || !onDesktopKnown ) {
@@ -533,14 +546,14 @@ void PDA::setPartnership( QThread */*thread*/, void * )
 
                     struct exchangeData_s exchangeData;
 
-                    exchangeData.partners[0] = partners[0];
-                    exchangeData.partners[1] = partners[1];
+                    exchangeData.partners[ 0 ] = partners[ 0 ];
+                    exchangeData.partners[ 1 ] = partners[ 1 ];
 
                     postThreadEvent( &PDA::removePartnershipDialog, &exchangeData, block );
 
                     deleteOnDevice = exchangeData.deleteOnDevice;
                 }
-// 6
+                // 6
                 advanceInitProgress( 1 );
 
                 if ( ( twoOnDevice && ( deleteOnDevice > 0 ) ) || !twoOnDevice ) {
@@ -561,7 +574,7 @@ void PDA::setPartnership( QThread */*thread*/, void * )
                                 error = true;
                             }
                         }
-// 7
+                        // 7
                         advanceInitProgress( 1 );
 
                         if ( ( deleteOnDevice & 2 ) && !error ) {
@@ -571,7 +584,7 @@ void PDA::setPartnership( QThread */*thread*/, void * )
                                 error = true;
                             }
                         }
-// 8
+                        // 8
                         advanceInitProgress( 1 );
                     }
 
@@ -584,29 +597,31 @@ void PDA::setPartnership( QThread */*thread*/, void * )
                         configDialog->setCaption( i18n( "Configuration of %1" ).arg( pdaName ) );
                         connect( syncDialog, SIGNAL( finished() ), configDialog, SLOT( writeConfig() ) );
                     }
-// 9
+                    // 9
                     advanceInitProgress( 1 );
 
                     kdDebug( 2120 ) << i18n( "Now we are ready to create the partnership ... " ) << endl;
 
-                    if ( matchmaker.partnerCreate( &matchingPartnerId ) && !error ) {
-// 10a
+                    if ( matchmaker.partnerCreate( &devicePartnerIndex ) && !error ) {
+                        // 10a
                         advanceInitProgress( 1 );
 
                         kdDebug( 2120 ) << i18n( "    success on the device ... now we set it on the desktop side" ) << endl;
-                        if ( matchmaker.getPartner( matchingPartnerId, &partner ) ) {
+
+                        struct MatchMaker::Partner partner;
+                        if ( matchmaker.getPartner( devicePartnerIndex, &partner ) ) {
                             kdDebug( 2120 ) << i18n( "        success" ) << endl;
-                            configDialog->setPartner( partner.name, partner.id );
+                            configDialog->setNewPartner( partner.name, partner.id );
                         } else {
                             kdDebug( 2120 ) << i18n( "        failed" ) << endl;
                             error = true;
                         }
-// 11
+                        // 11
                         advanceInitProgress( 1 );
                     } else {
                         kdDebug( 2120 ) << i18n( "    failed on the device" ) << endl;
                         error = true;
-// 10b
+                        // 10b
                         advanceInitProgress( 1 );
                     }
                 } else {
@@ -619,36 +634,35 @@ void PDA::setPartnership( QThread */*thread*/, void * )
             }
         }
         matchmaker.disconnect();
-// 12
+        // 12
         advanceInitProgress( 11 );
 
     } else {
-        kdDebug(2120) << i18n("failed") << endl;
+        kdDebug( 2120 ) << i18n( "failed" ) << endl;
         error = true;
     }
 
-    if (error) {
-        int status = 0;
-        postThreadEvent( &PDA::progressDialogCancel, &status, noBlock );
+    if ( error ) {
+        int *status = new int();
+        *status = 0;
+        postThreadEvent( &PDA::progressDialogCancel, status, noBlock );
     } else {
-        if (useGuest) {
+        if ( useGuest ) {
             kdDebug( 2120 ) << "Using Guest" << endl;
             delete configDialog;
             configDialog = new PdaConfigDialogImpl( "Guest", raki, "ConfigDialog", false );
             configDialog->setCaption( i18n( "Configuration of %1" ).arg( "Guest" ) );
             connect( syncDialog, SIGNAL( finished() ), configDialog, SLOT( writeConfig() ) );
             partnerOk = false;
-            partnerName = "Guest";
             partnerId = 0;
         } else {
-            postThreadEvent( &PDA::synchronizationTasks, 0, noBlock );
+            postThreadEvent(&PDA::synchronizationTasks, 0, noBlock);
             associatedMenu->setItemEnabled( syncItem, true );
             partnerOk = true;
-            partnerName = partner.name;
-            partnerId = partner.id;
         }
-        int status = 1;
-        postThreadEvent( &PDA::progressDialogCancel, &status, noBlock );
+        int *status = new int();
+        *status = 1;
+        postThreadEvent( &PDA::progressDialogCancel, status, noBlock );
     }
 }
 
@@ -658,7 +672,12 @@ void PDA::init()
     kdDebug( 2120 ) << i18n( "PDA-init" ) << endl;
 
     configDialog->readConnectionFile();
-    kdDebug(2120) << "IP: " << configDialog->getDeviceIp() << endl;
+    kdDebug( 2120 ) << "IP: " << configDialog->getDeviceIp() << endl;
+    kdDebug(2120) << "OsVersion: " << configDialog->getOsVersion() << endl;
+
+    if (configDialog->getOsVersion() > 3) {
+        this->rra->connect();
+    }
 
     initProgress = new InitProgress( raki, "InitProgress", true,
                                      WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WX11BypassWM );
@@ -672,24 +691,24 @@ void PDA::init()
 
     startWorkerThread( this, &PDA::setPartnership, NULL );
 
-    kdDebug(2120) << "Ende PDA::init()" << endl;
+    kdDebug( 2120 ) << "Ende PDA::init()" << endl;
 }
 
 
-bool PDA::synchronizationTasks( void * )
+void * PDA::synchronizationTasks( void * )
 {
-    RRA_SyncMgrType * objectType;
+    uint32_t objectType;
     QDateTime lastSynchronized;
     bool ret = true;
 
     if ( !typesRead ) {
         typesRead = true;
-        QMap<int, RRA_SyncMgrType *> types;
+        QValueList<uint32_t> types;
         if ( getSynchronizationTypes( &types ) ) {
-            QMapIterator<int, RRA_SyncMgrType *> it;
+            QValueListIterator<uint32_t> it;
             for ( it = types.begin() ; it != types.end(); ++it ) {
                 objectType = *it;
-                configDialog->addSyncTask( objectType, partnerId );
+                configDialog->addSyncTask(rra, objectType, partnerId);
             }
         } else {
             ret = false;
@@ -698,7 +717,7 @@ bool PDA::synchronizationTasks( void * )
 
     kdDebug( 2120 ) << i18n( "End PDA::syncronizationTasks()" ) << endl;
 
-    return ret;
+    return NULL;
 }
 
 
