@@ -41,6 +41,7 @@
 
 class SyncTaskListItem;
 class RemovePartnershipDialogImpl;
+class Rra;
 //typedef struct _ObjectType ObjectType;
 
 /**
@@ -64,11 +65,12 @@ public:
     uint32_t getPartnerId();
     QPtrList<SyncTaskListItem>& syncronizationTasks();
     void setNewPartner(QString partnerName, uint32_t partnerId);
-    void addSyncTask(RRA_SyncMgrType *objectType, uint32_t partnerId);
+    void addSyncTask(Rra *rra, uint32_t objectType, uint32_t partnerId);
     QPtrList<SyncTaskListItem>& getSyncTaskItemList();
     void clearConfig();
     bool readConnectionFile();
     virtual void show();
+    int getOsVersion();
 
 public slots:
     void writeConfig();
@@ -97,6 +99,7 @@ private:
     bool syncAtConnect;
     bool newPda;
     QString deviceIp;
+    int osVersion;
 };
 
 #endif
