@@ -299,11 +299,10 @@ void AGSync::doServerSync( AGReader *r, AGWriter *w, AGServerConfig *s, AGNetCtx
 }
 
 
-bool AGSync::preSync( QWidget *parent, Rra * /*rra*/,
-                      bool /*firstSynchronize*/, uint32_t /*partnerId*/ )
+bool AGSync::preSync( QWidget *parent, bool /*firstSynchronize*/, uint32_t /*partnerId*/ )
 {
     bool ret = true;
-    
+
     if ( configDialog->installClient() ) {
         AvantGoClientInstallationDialogImpl agcid;
 
@@ -341,11 +340,11 @@ bool AGSync::preSync( QWidget *parent, Rra * /*rra*/,
                 if ( !agClients.empty() ) {
                     install( agClients.first() );
                     configDialog->resetInstallClient();
-                    
+
                     for ( QStringList::Iterator it = extractedFiles.begin(); it != extractedFiles.end(); ++it ) {
                         KIO::NetAccess::del(*it, NULL);
                     }
-                    
+
                     KMessageBox::information( parent,
                                               i18n( "The AvantGo Client has been installed on your device.\n" \
                                                     "Please finish the installation on the device but do not " \
@@ -362,7 +361,7 @@ bool AGSync::preSync( QWidget *parent, Rra * /*rra*/,
             ret = false;
         }
     }
-    
+
     return ret;
 }
 
@@ -492,4 +491,9 @@ bool AGSync::sync()
 
     return true;
 }
+
+
+int AGSync::syncContext() {
+    return RakiSyncPlugin::ASYNCHRONOUS;
+}
 #endif
