@@ -47,7 +47,7 @@ class AGSyncConfigImpl;
 /**
 @author Volker Christian,,,
 */
-class AGSync : public RakiSyncPlugin 
+class AGSync : public RakiSyncPlugin
 {
 Q_OBJECT
 public:
@@ -55,7 +55,8 @@ public:
     ~AGSync();
     void createConfigureObject(KConfig *ksConfig);
     void configure();
-    bool preSync(QWidget *parent, Rra *rra, bool firstSynchronize, uint32_t partnerId);
+    bool preSync(QWidget *parent, bool firstSynchronize, uint32_t partnerId);
+    int syncContext();
 
 private:
     bool sync();
