@@ -27,12 +27,29 @@
 #include <klocale.h>
 #include <kdebug.h>
 
+class PartnershipCheckListItem : public QCheckListItem
+{
+    public:
+        PartnershipCheckListItem(QListView *listView, QString name, Type tt, int partnerId) :
+            QCheckListItem(listView, name, tt) {
+            this->partnerId = partnerId;
+        }
+
+        int getPartnerId() {
+            return partnerId;
+        }
+
+    private:
+        int partnerId;
+};
+
+
 RemovePartnershipDialogImpl::RemovePartnershipDialogImpl( QWidget* parent,
         const char* name, bool modal, WFlags fl )
  : RemovePartnershipDialog(parent, name, modal, fl )
-{   
+{
     partnershipListView->setFullWidth(true);
-    
+
 }
 
 
@@ -46,33 +63,32 @@ void RemovePartnershipDialogImpl::setPartnerships(QString partner1,
 {
     partnershipList.clear();
     partnershipListView->clear();
-    QCheckListItem *partnerItem1 = new QCheckListItem(partnershipListView,
-            partner1, QCheckListItem::CheckBox);
-    QCheckListItem *partnerItem2 = new QCheckListItem(partnershipListView,
-            partner2, QCheckListItem::CheckBox);
 
-    partnershipListView->insertItem(partnerItem1);
+    QCheckListItem *partnerItem1 = new PartnershipCheckListItem(partnershipListView,
+            partner1, QCheckListItem::CheckBox, 1);
+    QCheckListItem *partnerItem2 = new PartnershipCheckListItem(partnershipListView,
+            partner2, QCheckListItem::CheckBox, 2);
+
     partnershipList.append(partnerItem1);
-    partnershipListView->insertItem(partnerItem2);
     partnershipList.append(partnerItem2);
 }
 
 
 void RemovePartnershipDialogImpl::removePartnerships()
 {
-    kdDebug(2120) << i18n("Removing partnerships") << endl;
-    
-    QCheckListItem *first = partnershipList.first();
-    QCheckListItem *second = partnershipList.next();
-    
+    PartnershipCheckListItem *first = (PartnershipCheckListItem *) partnershipList.first();
+    PartnershipCheckListItem *second = (PartnershipCheckListItem *) partnershipList.next();
+
     if (first->isOn()) {
         partnershipListView->takeItem(first);
-        deletedItems |= 1;
+        deletedItems |= first->getPartnerId();
+        kdDebug(2120) << i18n("Removing partnership ") << first->getPartnerId() << endl;
     }
-    
+
     if (second->isOn()) {
         partnershipListView->takeItem(second);
-        deletedItems |= 2;
+        deletedItems |= second->getPartnerId();;
+        kdDebug(2120) << i18n("Removing partnership ") << second->getPartnerId() << endl;
     }
 }
 
@@ -82,13 +98,13 @@ int RemovePartnershipDialogImpl::showDialog(QString partner1, QString partner2,
     RemovePartnershipDialogImpl *dialog = new RemovePartnershipDialogImpl(
             parent, name, modal, fl);
     dialog->setPartnerships(partner1, partner2);
-    
+
     deletedItems = 0;
-    
+
     dialog->exec();
-    
+
     delete dialog;
-    
+
     return deletedItems;
 }
 
