@@ -31,6 +31,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <klistview.h>
 #include <qcursor.h>
 #include <qpoint.h>
 
@@ -39,10 +40,11 @@
 #include <kde_dmalloc.h>
 #endif
 
-SyncTaskListItem::SyncTaskListItem(QString pdaName, RRA_SyncMgrType *objectType,
-                                   QListView* listView, uint32_t partnerId)
-        : QCheckListItem(listView, objectType->name2, QCheckListItem::CheckBox)
+SyncTaskListItem::SyncTaskListItem(Rra *rra, QString pdaName, uint32_t objectType,
+                                   KListView* listView, uint32_t partnerId)
+        : QCheckListItem(listView, rra->getTypeForId(objectType)->name2, QCheckListItem::CheckBox)
 {
+    this->rra = rra,
     this->objectType = objectType;
     this->partnerId = partnerId;
     this->syncPlugin = NULL;
@@ -57,6 +59,7 @@ SyncTaskListItem::SyncTaskListItem(QString pdaName, RRA_SyncMgrType *objectType,
 SyncTaskListItem::~SyncTaskListItem()
 {
     if (syncPlugin != NULL) {
+        syncPlugin->unInit();
         delete syncPlugin;
     }
 }
@@ -131,19 +134,13 @@ bool SyncTaskListItem::isFirstSynchronization()
 
 RRA_SyncMgrType* SyncTaskListItem::getObjectType()
 {
-    return objectType;
+    return rra->getTypeForId(objectType);
 }
 
 
 QString SyncTaskListItem::getObjectTypeName()
 {
-    return objectType->name2;
-}
-
-
-void SyncTaskListItem::setObjectType(RRA_SyncMgrType *objectType)
-{
-    this->objectType = objectType;
+    return rra->getTypeForId(objectType)->name2;
 }
 
 
@@ -232,7 +229,7 @@ void SyncTaskListItem::clickedMenu(int item)
     if (offers.begin() != offers.end()) {
         for (it = offers.begin(); it != offers.end(); ++it) {
             KService::Ptr service = *it;
-            kdDebug(2120) << i18n("Select Name:") << " " 
+            kdDebug(2120) << i18n("Select Name:") << " "
             << service->name() + "; " << i18n("Library:") << " " <<
                     service->library() << endl;
             if (service->name() == itemMenu.text(item)) {
@@ -247,7 +244,7 @@ void SyncTaskListItem::clickedMenu(int item)
             }
         }
     }
-    
+
     createSyncPlugin(QCheckListItem::isOn());
     emit serviceChanged();
 }
@@ -270,8 +267,8 @@ void SyncTaskListItem::openPopup()
     if (offers.begin() != offers.end()) {
         for (it = offers.begin(); it != offers.end(); ++it) {
             KService::Ptr service = *it;
-            kdDebug(2120) << i18n("Open Name:") << " " 
-              << service->name() << "; " << i18n("Library:") << " " 
+            kdDebug(2120) << i18n("Open Name:") << " "
+              << service->name() << "; " << i18n("Library:") << " "
               << service->library() << endl;
             int item = itemMenu.insertItem(service->name());
             if (service->name() == preferedOfferTemp) {
@@ -305,11 +302,12 @@ int SyncTaskListItem::createSyncPlugin(bool state)
     int ret = 0;
 
     if (syncPlugin != NULL) {
+        syncPlugin->unInit();
         delete syncPlugin;
         syncPlugin = NULL;
     }
 
-    if (/*isOn()*/ state) {
+    if (state) {
         KTrader::OfferList offers;
 
         QString library = getPreferedLibrary();
@@ -339,7 +337,7 @@ int SyncTaskListItem::createSyncPlugin(bool state)
                         static_cast<RakiSyncFactory*> (factory);
                     syncPlugin = static_cast<RakiSyncPlugin*>
                                  (syncFactory->create());
-                    syncPlugin->init(objectType, pdaName, this->listView(), offer);
+                    syncPlugin->init(rra, this, pdaName, this->listView(), offer);
                     syncFactory->callme(); // Fake call to link correct.
                 } else {
                     kdDebug(2120) << i18n("Library no Raki-Plugin") << endl;
@@ -354,19 +352,19 @@ int SyncTaskListItem::createSyncPlugin(bool state)
     switch(ret) {
     case ERROR_NOSYNCHRONIZER:
         KMessageBox::information(this->listView(), "<p>" + i18n("No Synchronizer found for") + " <b>" +
-                QString(objectType->name2) + "</b></p>", QString(objectType->name2) + pdaName);
+                QString(rra->getTypeForId(objectType)->name2) + "</b></p>", QString(rra->getTypeForId(objectType)->name2) + pdaName);
         this->setOn(false);
         this->makePersistent();
         break;
     case ERROR_WRONGLIBRARYTYPE:
         KMessageBox::error(this->listView(), "<p>" + i18n("Wrong library type for") +" <b>" +
-                QString(objectType->name2) + "</b></p>", QString(objectType->name2) + pdaName);
+                QString(rra->getTypeForId(objectType)->name2) + "</b></p>", QString(rra->getTypeForId(objectType)->name2) + pdaName);
         this->setOn(false);
         this->makePersistent();
         break;
     case ERROR_NOFACTORY:
         KMessageBox::error(this->listView(), "<p>" + i18n("Wrong library type for") + " <b>" +
-                QString(objectType->name2) + "</b></p>", QString(objectType->name2) + pdaName);
+                QString(rra->getTypeForId(objectType)->name2) + "</b></p>", QString(rra->getTypeForId(objectType)->name2) + pdaName);
         this->setOn(false);
         this->makePersistent();
         break;
@@ -376,60 +374,79 @@ int SyncTaskListItem::createSyncPlugin(bool state)
 }
 
 
-bool SyncTaskListItem::synchronize(SyncThread *syncThread, Rra *rra)
+void SyncTaskListItem::syncReal(void *data) {
+    bool *ret = (bool *) data;
+
+    *ret = syncPlugin->doSync(syncThread, firstSynchronization, partnerId);
+}
+
+
+bool SyncTaskListItem::synchronize(SyncThread *syncThread)
 {
     bool ret = false;
+    this->syncThread = syncThread;
 
-    postSyncThreadEvent(SyncThread::setTask, (void *) qstrdup(i18n("Started").utf8()));
+    postSyncThreadEvent(&SyncThread::setTask, (void *) qstrdup(i18n("Started").utf8()));
     int *pSteps = new int;
     *pSteps = 1;
-    postSyncThreadEvent(SyncThread::setTotalSteps, pSteps);
+    postSyncThreadEvent(&SyncThread::setTotalSteps, pSteps);
 
     if (syncPlugin != NULL) {
-        kdDebug(2120) << i18n("Started syncing with") << " " << syncPlugin->serviceName() << endl;
 
-        ret = syncPlugin->doSync(syncThread, rra, this, firstSynchronization,
-                partnerId);
+        if (syncPlugin->syncContext() == RakiSyncPlugin::ASYNCHRONOUS) {
+            kdDebug(2120) << "----------------------------------------------" << endl;
+            kdDebug(2120) << i18n("*** Started asynchronous syncing with") << " " << syncPlugin->serviceName() << endl;
+            syncReal(&ret);
+            kdDebug(2120) << i18n("*** Finished asynchronous syncing with") << " " << syncPlugin->serviceName() << endl;
+            kdDebug(2120) << "----------------------------------------------" << endl;
+        } else {
+            kdDebug(2120) << "----------------------------------------------" << endl;
+            kdDebug(2120) << i18n("*** Started synchronous syncing with") << " " << syncPlugin->serviceName() << endl;
+            postSyncThreadEventBlock(&SyncThread::syncReal, &ret);
+            kdDebug(2120) << i18n("*** Finished synchronous syncing with") << " " << syncPlugin->serviceName() << endl;
+            kdDebug(2120) << "----------------------------------------------" << endl;
+        }
 
-        kdDebug(2120) << i18n("Finished syncing with") << " " << syncPlugin->serviceName() << endl;
-        int *pStep = new int;
+       int *pStep = new int;
         *pStep = totalSteps();
-        postSyncThreadEvent(SyncThread::setProgress, pStep);
+        postSyncThreadEvent(&SyncThread::setProgress, pStep);
 
         if (ret) {
             lastSynchronized = QDateTime(QDate::currentDate(),
                     QTime::currentTime());
             firstSynchronization = false;
-            postSyncThreadEvent(SyncThread::setTask,
+            postSyncThreadEventBlock(&SyncThread::setTask,
                     (void *) qstrdup(i18n("Finished").utf8()));
         } else {
-            postSyncThreadEvent(SyncThread::setTask, (void *)
+            postSyncThreadEventBlock(&SyncThread::setTask, (void *)
                     qstrdup(i18n("Error during synchronization").utf8()));
         }
     }
 
-    syncThread->synchronizeGui();
+    return ret;
+}
+
+
+bool SyncTaskListItem::preSync(QWidget *parent)
+{
+    bool ret;
+
+    ret = syncPlugin->preSync(parent, firstSynchronization, partnerId);
+    setTotalSteps(1);
 
     return ret;
 }
 
 
-bool SyncTaskListItem::preSync(QWidget *parent, Rra *rra)
+bool SyncTaskListItem::postSync(QWidget *parent)
 {
     bool ret;
-    
-    ret = syncPlugin->preSync(parent, rra, firstSynchronization, partnerId);
-    
-    return ret;
-}
 
+    ret = syncPlugin->postSync(parent, firstSynchronization, partnerId);
+
+    int totSteps = totalSteps();
+    setProgress(totSteps);
 
-bool SyncTaskListItem::postSync(QWidget *parent, Rra *rra)
-{
-    bool ret;
-    
-    ret = syncPlugin->postSync(parent, rra, firstSynchronization, partnerId);
-    
     return ret;
 }
 
