@@ -49,14 +49,15 @@ class SyncThread;
 class Rra;
 class RakiSyncPlugin;
 class KConfig;
+class KListView;
 typedef struct _ObjectType ObjectType;
 
 class SyncTaskListItem : public QObject, public QCheckListItem
 {
 Q_OBJECT
-    
+
 public:
-    SyncTaskListItem(QString pdaName, RRA_SyncMgrType* objectType, QListView* listView,
+    SyncTaskListItem(Rra *rra, QString pdaName, uint32_t objectType, KListView* listView,
             uint32_t partnerId);
 
     virtual ~SyncTaskListItem();
@@ -67,7 +68,6 @@ public:
     void setOn(bool state);
     RRA_SyncMgrType* getObjectType();
     QString getObjectTypeName();
-    void setObjectType(RRA_SyncMgrType *objectType);
     void setTotalSteps(int totalSteps);
     void setProgress(int progress);
     void advance(int offset);
@@ -78,26 +78,28 @@ public:
     KTrader::OfferList getOffers();
     void openPopup();
     QString getPreferedOffer();
-    QString getPreferedLibrary();  
+    QString getPreferedLibrary();
     void setPreferedOffer(QString preferedOffer);
     void setPreferedLibrary(QString preferedLibrary);
-    bool synchronize(SyncThread *syncThread, Rra *rra);
-    bool preSync(QWidget *parent, Rra *rra);
-    bool postSync(QWidget *parent, Rra *rra);
+    bool synchronize(SyncThread *syncThread);
+    bool synSync(SyncThread *syncThread);
+    bool preSync(QWidget *parent);
+    bool postSync(QWidget *parent);
     void setLastSynchronized(QDateTime lastSynchronized);
     void setFirstSynchronization(bool firstSynchronization);
     bool isFirstSynchronization();
     QDateTime &getLastSynchronized();
     void configure();
+    void syncReal(void *data);
 
 private slots:
     void clickedMenu(int item);
-    
+
 protected:
     virtual void stateChange(bool state);
 
 private:
-    RRA_SyncMgrType *objectType;
+    uint32_t objectType;
     bool isOnStore;
     KProgress *progress;
     QLabel *taskLabelWidget;
@@ -113,10 +115,12 @@ private:
     bool firstSynchronization;
     int createSyncPlugin(bool state);
     RakiSyncPlugin *syncPlugin;
+    SyncThread *syncThread;
+    Rra *rra;
     enum {
         ERROR_NOFACTORY = 1, ERROR_WRONGLIBRARYTYPE, ERROR_NOSYNCHRONIZER
     };
-    
+
 signals:
     void stateChanged(bool state);
     void serviceChanged();
